#!/usr/bin/env python3
# THIS "versionfile" IS GENERATED BY version-pioneer-0.0.12
# by evaluating the original versionscript and storing the computed versions as a constant.

def get_version_dict():
    return {'version': '0.0.12', 'full_revisionid': '33555d58955e4e1b94a7282631d8fb05ac4fba10', 'dirty': False, 'error': None, 'date': '2025-02-07T05:00:11+0000'}


if __name__ == "__main__":
    import json

    print(json.dumps(get_version_dict()))